@@ -6,7 +6,7 @@ cat("\n")
 cat("***********************************************************************\n")
 cat("                                                                     \n")
 cat("                                  bear                               \n")
-cat("                                v 2.4.4                              \n")   
+cat("                                v 2.5.0                              \n")   
 cat("                    http://pkpd.kmu.edu.tw/bear                      \n")
 cat("                                                                     \n")
 cat(" This package is designed to analyze average bioequivalence (ABE)    \n")
@@ -14,10 +14,10 @@ cat(" (NCA -> ANOVA) or bioavailability (NCA only) data, with study       \n")
 cat(" design of a standard RT/TR 2-treatment, 2-sequence, and 2-period,   \n")
 cat(" crossover design (2x2x2), or a replicate ABE study including        \n")
 cat(" 2-treatment, 2-sequence, with more than 2 periods (i.e., 2x2x3/     \n")
-cat(" 2x2x4/.../2x2x6), or a parallel ABE study (2x2x1).  Bear can be     \n")
-cat(" used for SINGLE-DOSE or MULTIPLE-DOSE BE STUDY right now.           \n")
+cat(" 2x2x4/.../2x2x6), or a parallel ABE study (2x2x1). Bear can be      \n")
+cat(" used for SINGLE-DOSE or MULTIPLE-DOSE BE STUDY.                     \n")
 cat("                                                                     \n")
 cat("                   Please type 'go()' to get started.                \n")
 cat("                                                                     \n")
 cat("***********************************************************************\n")
-}
+}
\ No newline at end of file
